@@ -1,2 +1,2 @@
 # from gistools import raster, vector, rec, network, datasets, osm
-from gistools import raster, vector, rec, network, osm
+from gistools import raster, vector, rec, network, osm, data_io
